@@ -41,6 +41,7 @@
 #include <gdk/gdk.h>
 #include <gst/fft/gstfftf32.h>
 #include <gst/pbutils/pbutils.h>
+#include <gst/tag/tag.h>
 
 #if defined(GDK_WINDOWING_X11)
 #  include <gdk/gdkx.h>
@@ -141,14 +142,17 @@ struct BansheePlayer {
     gboolean   rgvolume_in_pipeline;
 
     gint equalizer_status;
+    gdouble current_volume;
     
     // Pipeline/Playback State
-    GMutex *mutex;
+    GMutex *video_mutex;
+    GMutex *replaygain_mutex;
     GstState target_state;
     gboolean buffering;
     gchar *cdda_device;
     gboolean in_gapless_transition;
     gboolean supports_stream_volume;
+    gboolean audiosink_has_volume;
     
     // Video State
     BpVideoDisplayContextType video_display_context_type;
