@@ -2,10 +2,10 @@ using System;
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: ApplicationVersion ("1.9.6", "1.9.6")]
-[assembly: ApplicationBuildInformation ("git-checkout", "freebsd8.2", "amd64", "2011-03-24 09:50:43 MYT")]
+[assembly: ApplicationVersion ("2.0.1", "2.0")]
+[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "i686", "2011-05-02 13:47:13 CDT")]
 
-[assembly: AssemblyVersion ("1.9.0.0")]
+[assembly: AssemblyVersion ("2.0.0.0")]
 [assembly: AssemblyTitle ("Banshee")]
 [assembly: AssemblyDescription ("Banshee Media Player")]
 [assembly: AssemblyCopyright ("Copyright (C) 2005-2010 Novell Inc. and others")]
