@@ -40,6 +40,7 @@ using Banshee.MediaEngine;
 using Banshee.ServiceStack;
 using Banshee.Configuration;
 using Banshee.Preferences;
+using Banshee.Collection;
 
 namespace Banshee.GStreamer
 {
@@ -104,6 +105,7 @@ namespace Banshee.GStreamer
 
         private bool next_track_pending;
         private SafeUri pending_uri;
+        private bool pending_maybe_video;
 
         private bool buffering_finished;
         private bool xid_is_set = false;
@@ -181,6 +183,11 @@ namespace Banshee.GStreamer
 
         protected override void Initialize ()
         {
+            if (ServiceManager.Get<Banshee.GStreamer.Service> () == null) {
+                var service = new Banshee.GStreamer.Service ();
+                ((IExtensionService)service).Initialize ();
+            }
+
             if (!bp_initialize_pipeline (handle)) {
                 bp_destroy (handle);
                 handle = new HandleRef (this, IntPtr.Zero);
@@ -192,10 +199,11 @@ namespace Banshee.GStreamer
             InstallPreferences ();
             ReplayGainEnabled = ReplayGainEnabledSchema.Get ();
             GaplessEnabled = GaplessEnabledSchema.Get ();
+            Log.InformationFormat ("GStreamer version {0}, gapless: {1}, replaygain: {2}", gstreamer_version_string (), GaplessEnabled, ReplayGainEnabled);
 
             is_initialized = true;
 
-            if (!bp_supports_stream_volume (handle)) {
+            if (!bp_audiosink_has_volume (handle)) {
                 Volume = (ushort)PlayerEngineService.VolumeSchema.Get ();
             }
         }
@@ -215,13 +223,13 @@ namespace Banshee.GStreamer
             base.Close (fullShutdown);
         }
 
-        protected override void OpenUri (SafeUri uri)
+        protected override void OpenUri (SafeUri uri, bool maybeVideo)
         {
             // The GStreamer engine can use the XID of the main window if it ever
             // needs to bring up the plugin installer so it can be transient to
             // the main window.
             if (!xid_is_set) {
-                IPropertyStoreExpose service = ServiceManager.Get<IService> ("GtkElementsService") as IPropertyStoreExpose;
+                var service = ServiceManager.Get ("GtkElementsService") as IPropertyStoreExpose;
                 if (service != null) {
                     bp_set_application_gdk_window (handle, service.PropertyStore.Get<IntPtr> ("PrimaryWindow.RawHandle"));
                 }
@@ -230,7 +238,7 @@ namespace Banshee.GStreamer
 
             IntPtr uri_ptr = GLib.Marshaller.StringToPtrGStrdup (uri.AbsoluteUri);
             try {
-                if (!bp_open (handle, uri_ptr)) {
+                if (!bp_open (handle, uri_ptr, maybeVideo)) {
                     throw new ApplicationException ("Could not open resource");
                 }
             } finally {
@@ -248,7 +256,7 @@ namespace Banshee.GStreamer
             bp_pause (handle);
         }
 
-        public override void SetNextTrackUri (SafeUri uri)
+        public override void SetNextTrackUri (SafeUri uri, bool maybeVideo)
         {
             next_track_pending = false;
             if (next_track_set.WaitOne (0, false)) {
@@ -256,6 +264,7 @@ namespace Banshee.GStreamer
                 // This means that we've missed the window for gapless.
                 // Save this URI to be played when we receive EOS.
                 pending_uri = uri;
+                pending_maybe_video = maybeVideo;
                 return;
             }
             // If there isn't a next track for us, release the block on the about-to-finish callback.
@@ -265,7 +274,7 @@ namespace Banshee.GStreamer
             }
             IntPtr uri_ptr = GLib.Marshaller.StringToPtrGStrdup (uri.AbsoluteUri);
             try {
-                bp_set_next_track (handle, uri_ptr);
+                bp_set_next_track (handle, uri_ptr, maybeVideo);
             } finally {
                 GLib.Marshaller.Free (uri_ptr);
                 next_track_set.Set ();
@@ -295,25 +304,31 @@ namespace Banshee.GStreamer
 
         private void OnEos (IntPtr player)
         {
+            StopIterating ();
             Close (false);
             OnEventChanged (PlayerEvent.EndOfStream);
-            if (!next_track_pending) {
+            if (!next_track_pending &&
+                (!GaplessEnabled || (CurrentTrack != null && CurrentTrack.HasAttribute (TrackMediaAttributes.VideoStream)))) {
+                // We don't request next track in OnEoS if gapless playback is enabled and current track has no video stream contained.
+                // The request next track is already called in OnAboutToFinish().
                 OnEventChanged (PlayerEvent.RequestNextTrack);
             } else if (pending_uri != null) {
                 Log.Warning ("[Gapless] EOS signalled while waiting for next track.  This means that Banshee " +
                     "was too slow at calculating what track to play next.  " +
                     "If this happens frequently, please file a bug");
                 OnStateChanged (PlayerState.Loading);
-                OpenUri (pending_uri);
+                OpenUri (pending_uri, pending_maybe_video);
                 Play ();
                 pending_uri = null;
-            } else {
+            } else if (!GaplessEnabled || (CurrentTrack != null && CurrentTrack.HasAttribute (TrackMediaAttributes.VideoStream))) {
                 // This should be unreachable - the RequestNextTrack event is delegated to the main thread
                 // and so blocks the bus callback from delivering the EOS message.
                 //
                 // Playback should continue as normal from here, when the RequestNextTrack message gets handled.
                 Log.Warning ("[Gapless] EndOfStream message received before the next track has been set.  " +
                     "If this happens frequently, please file a bug");
+            } else {
+                Log.Debug ("[Gapless] Reach the last music under repeat off mode");
             }
         }
 
@@ -329,6 +344,7 @@ namespace Banshee.GStreamer
         {
             if (iterate_timeout_id > 0) {
                 GLib.Source.Remove (iterate_timeout_id);
+                iterate_timeout_id = 0;
             }
 
             iterate_timeout_id = GLib.Timeout.Add (200, OnIterate);
@@ -338,6 +354,7 @@ namespace Banshee.GStreamer
         {
             if (iterate_timeout_id > 0) {
                 GLib.Source.Remove (iterate_timeout_id);
+                iterate_timeout_id = 0;
             }
         }
 
@@ -345,10 +362,14 @@ namespace Banshee.GStreamer
         {
             if (GaplessEnabled) {
                 // Must do it here because the next track is already playing.
-                ServiceManager.PlayerEngine.IncrementLastPlayed (1.0);
 
-                OnEventChanged (PlayerEvent.EndOfStream);
-                OnEventChanged (PlayerEvent.StartOfStream);
+                // If the state is anything other than loaded, assume we were just playing a track and should
+                // EoS it and increment its playcount etc.
+                if (CurrentState != PlayerState.Loaded) {
+                    ServiceManager.PlayerEngine.IncrementLastPlayed (1.0);
+                    OnEventChanged (PlayerEvent.EndOfStream);
+                    OnEventChanged (PlayerEvent.StartOfStream);
+                }
             }
         }
 
@@ -411,7 +432,7 @@ namespace Banshee.GStreamer
         {
             ready_timeout = 0;
             var uri = CurrentUri;
-            if (CurrentState == PlayerState.Loading && uri != null && uri.IsLocalPath) {
+            if (CurrentState == PlayerState.Loading && Position == 0 && uri != null && uri.IsLocalPath) {
                 // This is a dirty workaround.  I was seeing the playback get stuck on track transition,
                 // about one in 20 songs, where it would load the new track's duration, but be stuck at 0:00,
                 // but if I moved the seek slider it would unstick it, hence setting Position...
@@ -563,7 +584,7 @@ namespace Banshee.GStreamer
                 }
 
                 bp_set_volume (handle, value / 100.0);
-                if (!bp_supports_stream_volume (handle)) {
+                if (!bp_audiosink_has_volume (handle)) {
                     PlayerEngineService.VolumeSchema.Set ((int)value);
                 }
 
@@ -682,10 +703,52 @@ namespace Banshee.GStreamer
                     }
                 } else {
                     gapless_enabled = false;
+                    next_track_pending = false;
                 }
             }
         }
 
+        public override int SubtitleCount {
+            get { return bp_get_subtitle_count (handle); }
+        }
+
+        public override int SubtitleIndex {
+            set { bp_set_subtitle (handle, value); }
+        }
+
+        public override SafeUri SubtitleUri {
+            set {
+                if (value != null) {
+                    IntPtr uri_ptr = GLib.Marshaller.StringToPtrGStrdup (value.AbsoluteUri);
+                    try {
+                        bp_set_subtitle_uri (handle, uri_ptr);
+                    } finally {
+                        GLib.Marshaller.Free (uri_ptr);
+                    }
+                }
+            }
+            get {
+                IntPtr uri_ptr = IntPtr.Zero;
+                try {
+                    uri_ptr = bp_get_subtitle_uri (handle);
+                    string uri = GLib.Marshaller.Utf8PtrToString (uri_ptr);
+                    return new SafeUri(uri);
+                } finally {
+                    GLib.Marshaller.Free (uri_ptr);
+                }
+            }
+        }
+
+        public override string GetSubtitleDescription (int index)
+        {
+            IntPtr desc_ptr = IntPtr.Zero;
+            try {
+                desc_ptr = bp_get_subtitle_description (handle, index);
+                return GLib.Marshaller.Utf8PtrToString (desc_ptr);
+            } finally {
+                GLib.Marshaller.Free (desc_ptr);
+            }
+        }
 
 #region ISupportClutter
 
@@ -852,7 +915,7 @@ namespace Banshee.GStreamer
         private static extern bool bp_supports_gapless (HandleRef player);
 
         [DllImport ("libbanshee.dll")]
-        private static extern bool bp_open (HandleRef player, IntPtr uri);
+        private static extern bool bp_open (HandleRef player, IntPtr uri, bool maybeVideo);
 
         [DllImport ("libbanshee.dll")]
         private static extern void bp_stop (HandleRef player, bool nullstate);
@@ -864,7 +927,7 @@ namespace Banshee.GStreamer
         private static extern void bp_play (HandleRef player);
 
         [DllImport ("libbanshee.dll")]
-        private static extern bool bp_set_next_track (HandleRef player, IntPtr uri);
+        private static extern bool bp_set_next_track (HandleRef player, IntPtr uri, bool maybeVideo);
 
         [DllImport ("libbanshee.dll")]
         private static extern void bp_set_volume (HandleRef player, double volume);
@@ -880,7 +943,7 @@ namespace Banshee.GStreamer
         private static extern bool bp_can_seek (HandleRef player);
 
         [DllImport ("libbanshee.dll")]
-        private static extern bool bp_supports_stream_volume (HandleRef player);
+        private static extern bool bp_audiosink_has_volume (HandleRef player);
 
         [DllImport ("libbanshee.dll")]
         private static extern bool bp_set_position (HandleRef player, ulong time_ms);
@@ -944,5 +1007,23 @@ namespace Banshee.GStreamer
 
         [DllImport ("libbanshee.dll")]
         private static extern IntPtr clutter_gst_video_sink_new (IntPtr texture);
-    }
+
+        [DllImport ("libbanshee.dll")]
+        private static extern int bp_get_subtitle_count (HandleRef player);
+
+        [DllImport ("libbanshee.dll")]
+        private static extern void bp_set_subtitle (HandleRef player, int index);
+
+        [DllImport ("libbanshee.dll")]
+        private static extern void bp_set_subtitle_uri (HandleRef player, IntPtr uri);
+
+        [DllImport ("libbanshee.dll")]
+        private static extern IntPtr bp_get_subtitle_uri (HandleRef player);
+
+        [DllImport ("libbanshee.dll")]
+        private static extern IntPtr bp_get_subtitle_description (HandleRef player, int index);
+
+        [DllImport ("libbanshee.dll")]
+        private static extern string gstreamer_version_string ();
+   }
 }
