@@ -73,7 +73,7 @@ namespace Booter
     {
         public static void Main ()
         {
-            Paths.ApplicationName = Application.InternalName;
+            Application.InitializePaths ();
 
             if (CheckHelpVersion ()) {
                 return;
@@ -99,7 +99,11 @@ namespace Booter
             } else if (ApplicationContext.CommandLine.Contains ("client")) {
                 BootClient (Path.GetFileNameWithoutExtension (ApplicationContext.CommandLine["client"]));
             } else {
-                BootClient ("Nereid");
+                if (PlatformDetection.IsMeeGo) {
+                    BootClient ("MeeGo");
+                } else {
+                    BootClient ("Nereid");
+                }
             }
         }
 
@@ -141,7 +145,7 @@ namespace Booter
 
         private static void ShowHelp ()
         {
-            Console.WriteLine ("Usage: {0} [options...] [files|URIs...]", "banshee-1");
+            Console.WriteLine ("Usage: {0} [options...] [files|URIs...]", "banshee");
             Console.WriteLine ();
 
             Layout commands = new Layout (
