@@ -28,7 +28,6 @@
 
 using System;
 using System.Collections.Generic;
-using System.Data;
 using System.IO;
 
 using Hyena;
@@ -210,7 +209,7 @@ namespace Banshee.Collection.Database
 
             bool is_new = (TrackId == 0);
             if (is_new) {
-                DateAdded = DateUpdated = DateTime.Now;
+                LastSyncedStamp = DateAdded = DateUpdated = DateTime.Now;
             }
 
             ProviderSave ();
@@ -641,6 +640,10 @@ namespace Banshee.Collection.Database
                 if (rating != value) {
                     rating = value;
                     Save (true, BansheeQuery.RatingField);
+                    if (TrackEqual (ServiceManager.PlayerEngine.CurrentTrack)) {
+                        ServiceManager.PlayerEngine.CurrentTrack.Rating = value;
+                        ServiceManager.PlayerEngine.TrackInfoUpdated ();
+                    }
                 }
             }
         }
