@@ -27,17 +27,20 @@
 //
 
 using System;
+using System.Linq;
+using System.Collections.Generic;
+using System.Threading;
+
+using Hyena;
+using Hyena.Query;
+
 using Banshee.Base;
 using Banshee.Collection.Database;
 using Banshee.ServiceStack;
 using Banshee.Library;
-using System.Collections.Generic;
-using System.Threading;
 using Banshee.Hardware;
 using Banshee.Sources;
 using Banshee.I18n;
-using Hyena.Query;
-using Hyena;
 using Banshee.Playlist;
 
 namespace Banshee.Dap.AppleDevice
@@ -75,7 +78,7 @@ namespace Banshee.Dap.AppleDevice
 
             if (!Volume.IsMounted) {
                 Hyena.Log.Information ("AppleDeviceSource is ignoring unmounted volume " + Volume.Name);
-                throw new InvalidOperationException ();
+                throw new InvalidDeviceException ();
             }
             
             Device = new GPod.Device (Volume.MountPoint);
@@ -92,7 +95,10 @@ namespace Banshee.Dap.AppleDevice
             SupportsVideo = Device.SupportsVideo;
 
             Initialize ();
-            GPod.ITDB.InitIpod (Volume.MountPoint, Device.IpodInfo.ModelNumber, Name);
+            GPod.ITDB.InitIpod (Volume.MountPoint, Device.IpodInfo == null ? null : Device.IpodInfo.ModelNumber, Name);
+
+            // HACK: ensure that m4a, and mp3 are set as accepted by the device; bgo#633552
+            AcceptableMimeTypes = (AcceptableMimeTypes ?? new string [0]).Union (new string [] { "taglib/m4a", "taglib/mp3" }).ToArray ();
 
             // FIXME: Properly parse the device, color and generation and don't use the fallback strings
 
@@ -171,7 +177,7 @@ namespace Banshee.Dap.AppleDevice
                 try {
                     MediaDatabase = new GPod.ITDB (Device.Mountpoint);
                 } catch (GLib.GException e) {
-                    Log.Exception ("iPod database could be loaded, creating a new one", e);
+                    Log.Exception ("iPod database could not be loaded, creating a new one", e);
                     if (GPod.ITDB.InitIpod (Volume.MountPoint, null, Volume.Name)) {
                         // this may throw again. In the future we need to implement some kind of alert
                         // mechanism to let the user know that something more serious is wrong with their
@@ -196,7 +202,14 @@ namespace Banshee.Dap.AppleDevice
                 });
             }
 
+            var invalid_tracks = new List<GPod.Track> ();
             foreach (var ipod_track in MediaDatabase.Tracks) {
+
+                if (String.IsNullOrEmpty (ipod_track.IpodPath)) {
+                    invalid_tracks.Add (ipod_track);
+                    continue;
+                }
+
                 try {
                     var track = new AppleDeviceTrackInfo (ipod_track);
                     if (!tracks_map.ContainsKey (track.TrackId)) {
@@ -208,6 +221,13 @@ namespace Banshee.Dap.AppleDevice
                     Log.Exception (e);
                 }
             }
+            if (invalid_tracks.Count > 0) {
+                Log.Warning (String.Format ("Found {0} invalid tracks on the device", invalid_tracks.Count));
+                foreach (var track in invalid_tracks) {
+                    DeleteTrack (track, false);
+                }
+            }
+
 
             Hyena.Data.Sqlite.HyenaSqliteCommand insert_cmd = new Hyena.Data.Sqlite.HyenaSqliteCommand (
                 @"INSERT INTO CorePlaylistEntries (PlaylistID, TrackID)
@@ -402,6 +422,25 @@ namespace Banshee.Dap.AppleDevice
             }
         }
 
+
+        private void DeleteTrack (GPod.Track track, bool removeFile)
+        {
+            foreach (var playlist in MediaDatabase.Playlists) {
+                playlist.Tracks.Remove (track);
+            }
+
+            if (SupportsPodcasts && track.MediaType == GPod.MediaType.Podcast) {
+                MediaDatabase.PodcastsPlaylist.Tracks.Remove (track);
+            }
+
+            MediaDatabase.MasterPlaylist.Tracks.Remove (track);
+            MediaDatabase.Tracks.Remove (track);
+
+            if (removeFile) {
+                Banshee.IO.File.Delete (new SafeUri (GPod.ITDB.GetLocalPath (Device, track)));
+            }
+        }
+
         protected override void AddTrackToDevice (DatabaseTrackInfo track, SafeUri fromUri)
         {
             lock (sync_mutex) {
@@ -569,18 +608,7 @@ namespace Banshee.Dap.AppleDevice
                     if (track.IpodTrack != null) {
                         UpdateProgress (progressUpdater, message, total - tracks_to_remove.Count, total);
 
-                        foreach (var playlist in MediaDatabase.Playlists) {
-                            playlist.Tracks.Remove (track.IpodTrack);
-                        }
-
-                        if (SupportsPodcasts && track.IpodTrack.MediaType == GPod.MediaType.Podcast) {
-                            MediaDatabase.PodcastsPlaylist.Tracks.Remove (track.IpodTrack);
-                        }
-
-                        MediaDatabase.MasterPlaylist.Tracks.Remove (track.IpodTrack);
-                        MediaDatabase.Tracks.Remove (track.IpodTrack);
-
-                        Banshee.IO.File.Delete (new SafeUri (GPod.ITDB.GetLocalPath (Device, track.IpodTrack)));
+                        DeleteTrack (track.IpodTrack, true);
                     } else {
                         Log.Error ("The ipod track was null");
                     }
