@@ -34,6 +34,7 @@ namespace Banshee.PlayQueue
     [Interface ("org.bansheeproject.Banshee.PlayQueue")]
     public interface IPlayQueue
     {
-        void EnqueueUri (string uri);
+        void EnqueueUri (string uri, bool prepend);
+        void Clear ();
     }
 }
