@@ -40,18 +40,27 @@ namespace Migo.Syndication
     public class MigoModelProvider<T> : SqliteModelProvider<T> where T : MigoItem<T>, ICacheableItem, new()
     {
         private Dictionary<long, T> full_cache = new Dictionary<long, T> ();
-        
+
         public MigoModelProvider (HyenaSqliteConnection connection, string table_name) : base (connection, table_name)
         {
         }
 
+        public MigoModelProvider (HyenaSqliteConnection connection, string table_name, bool check) : base (connection, table_name, check)
+        {
+        }
+
+        public void ClearCache ()
+        {
+            full_cache.Clear ();
+        }
+
 #region Overrides
-                
+
         public override T FetchSingle (long id)
         {
             return GetCached (id) ?? CacheResult (base.FetchSingle (id));
         }
-        
+
         public override void Save (T target)
         {
             base.Save (target);
@@ -60,27 +69,27 @@ namespace Migo.Syndication
             }
         }
 
-        public override T Load (System.Data.IDataReader reader)
+        public override T Load (IDataReader reader)
         {
             return GetCached (PrimaryKeyFor (reader)) ?? CacheResult (base.Load (reader));
         }
-        
+
         public override void Delete (long id)
         {
             full_cache.Remove (id);
             base.Delete (id);
         }
-        
+
         public override void Delete (IEnumerable<T> items)
         {
             foreach (T item in items) {
                 if (item != null)
                     full_cache.Remove (PrimaryKeyFor (item));
             }
-                
+
             base.Delete (items);
         }
-        
+
 #endregion
 
 #region Utility Methods
@@ -93,7 +102,7 @@ namespace Migo.Syndication
                 return null;
             }
         }
-        
+
         private T CacheResult (T item)
         {
             full_cache[item.DbId] = item;
@@ -101,6 +110,6 @@ namespace Migo.Syndication
         }
 
 #endregion
-        
+
     }
-}
\ No newline at end of file
+}
